@@ -33,7 +33,7 @@ class Configuration:
     def __init__(self):
         ''' initialize the configuration library '''
         from usersconfig.configuration import Configuration
-        self._loader = Configuration(__name__)
+        self._loader = Configuration("PriceDb")
         self.config = None
 
     @property
