@@ -33,13 +33,13 @@ class Price(Base):
             symbol = ""
         formatted_symbol = f"{symbol:<13}"
 
-        return f"<Price ({formatted_symbol},{self.date} {self.time},{actual_value_str:>6})>"
+        return f"<Price ({formatted_symbol},{self.date} {self.time},{actual_value_str:>6} {self.currency})>"
 
 
 class Security(Base):
     """ The security / symbol entity
-    Adding a record here should enable it for updated automatically.
-    Contains the link to Yahoo symbol and should replace SymbolMap.
+    Adding a record here should enable it for update automatically.
+    Contains the link to the Yahoo symbol and should replace SymbolMap.
     """
     __tablename__ = "security"
 
